import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { PathService } from '../../service/core/path.service';
import { CDTO_path, CVO_path, FVO_path, QDTO_path, QVO_path, UDTO_path, UVAO_path } from '../../interface/core/path.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['申办流程'])
@Controller('/path')
export class PathController extends BaseController {
  @Inject()
  service: PathService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_path })
  async create(@Body() data: CDTO_path) {
    const dbData = await this.service.create(data);
    const result = new CVO_path(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_path })
  async query(@Query() filter: QDTO_path, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit, sort: { sort: 1 } });
    const data = [];
    for (const i of list) {
      const newData = new QVO_path(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_path })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_path(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_path })
  async update(@Param('id') id: string, @Body() body: UDTO_path) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
