import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { PersonnelService } from '../../service/core/personnel.service';
import { CDTO_personnel, CVO_personnel, FVO_personnel, QDTO_personnel, QVO_personnel, UDTO_personnel, UVAO_personnel } from '../../interface/core/personnel.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['公证员'])
@Controller('/personnel')
export class PersonnelController extends BaseController {
  @Inject()
  service: PersonnelService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_personnel })
  async create(@Body() data: CDTO_personnel) {
    const dbData = await this.service.create(data);
    const result = new CVO_personnel(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_personnel })
  async query(@Query() filter: QDTO_personnel, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_personnel(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_personnel })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_personnel(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_personnel })
  async update(@Param('id') id: string, @Body() body: UDTO_personnel) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
